二代的ffm3u8模块修改了第一代一些问题并提供了IV的写入使模块的使用更加多元化，当然相比于第一代第二代也并没有太多的改变，模块的使用还是有太多的限制，不过我还会继续更新的，希望大家喜欢！ 
<hr>
<p><strong>安装方式：</strong>pip install ffm3u8</p>
<hr>
<br>使用方法：<br>
<strong>解密方法：</strong><br>
ffm3u8.get_url_key(name='m3u8的路径', name2='ts的前域名', op='保存的路径（使用/后面需要加上/如：D:/xuexipan/python/crawler/视频/新建文件夹/）', headers=请求头, key_url='密钥的url', IV='填入IV没有则填入16个0')<br>
<strong>不解密的方法：</strong><br>
ffm3u8.get_aio_url(name='m3u8的路径', name2='ts的前域名', op='保存的路径（使用/后面需要加上/如：D:/xuexipan/python/crawler/视频/新建文件夹/）', headers=请求头)<br>
<hr>
<p>联系电话：181 2874 4689（微信，QQ同号）（备注来因）</p>
<p>邮箱：13360350080@163.com</p>
<p>希望大家可以多多留意，多多提建议！</p>
<hr>
<p>感谢@企鹅诶i提供的技术支持！</p>
<hr>
<p>感谢re, aiohttp, asyncio, aiofiles, AES, Crypto模块提供的模块支持非常感谢！</p>
<hr>
<p><strong>告示：</strong>任何人使用本模块做的违规违法，及任何的利益纠纷的产生的责任，模块制作所有人概不负责</p>
